@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.7029";
+our $VERSION = "1.7100";
 
 =encoding utf8
 
@@ -38,11 +38,11 @@ install, and later upgrade.
 
 You can also use the latest cpanminus to install cpanminus itself:
 
-    curl -L https://cpanmin.us | perl - --sudo App::cpanminus
+    curl -L http://cpanmin.us | perl - --sudo App::cpanminus
 
 This will install C<cpanm> to your bin directory like
-C</usr/local/bin> and you'll need the C<--sudo> option to write to
-the directory, unless you configured C<INSTALL_BASE> with L<local::lib>.
+C</usr/local/bin> (unless you configured C<INSTALL_BASE> with
+L<local::lib>), so you probably need the C<--sudo> option.
 
 =head2 Installing to local perl (perlbrew)
 
@@ -51,7 +51,7 @@ tools like L<perlbrew>, you don't need the C<--sudo> option, since
 you're most likely to have a write permission to the perl's library
 path. You can just do:
 
-    curl -L https://cpanmin.us | perl - App::cpanminus
+    curl -L http://cpanmin.us | perl - App::cpanminus
 
 to install the C<cpanm> executable to the perl's bin path, like
 C<~/perl5/perlbrew/bin/cpanm>.
@@ -61,21 +61,12 @@ C<~/perl5/perlbrew/bin/cpanm>.
 You can also copy the standalone executable to whatever location you'd like.
 
     cd ~/bin
-    curl -L https://cpanmin.us/ -o cpanm
+    curl -LO http://xrl.us/cpanm
     chmod +x cpanm
+    # edit shebang if you don't have /usr/bin/env
 
 This just works, but be sure to grab the new version manually when you
-upgrade because C<--self-upgrade> might not work with this installation setup.
-
-=head2 Troubleshoot: HTTPS warnings
-
-When you run C<curl> commands above, you may encounter SSL handshake
-errors or certification warnings. This is due to your HTTP client
-(curl) being old, or SSL certificates installed on your system needs
-to be updated.
-
-You might need to update the software or system if you can, or
-use the C<-k> option with curl.
+upgrade because C<--self-upgrade> might not work for this.
 
 =head1 DEPENDENCIES
 
@@ -103,12 +94,32 @@ Module::Build (core in 5.10)
 
 =head1 QUESTIONS
 
-=head2 How does cpanm get/parse/update the CPAN index?
+=head2 Another CPAN installer?
+
+OK, the first motivation was this: the CPAN shell runs out of memory (or swaps
+heavily and gets really slow) on Slicehost/linode's most affordable plan with
+only 256MB RAM. Should I pay more to install perl modules from CPAN? I don't
+think so.
+
+=head2 But why a new client?
+
+First of all, let me be clear that CPAN and CPANPLUS are great tools
+I've used for I<literally> years (you know how many modules I have on
+CPAN, right?). I really respect their efforts of maintaining the most
+important tools in the CPAN toolchain ecosystem.
+
+However, for less experienced users (mostly from outside the Perl community),
+or even really experienced Perl developers who know how to shoot themselves in
+their feet, setting up the CPAN toolchain often feels like yak shaving,
+especially when all they want to do is just install some modules and start
+writing code.
+
+=head2 Zero-conf? How does this module get/parse/update the CPAN index?
 
 It queries the CPAN Meta DB site at L<http://cpanmetadb.plackperl.org/>.
 The site is updated at least every hour to reflect the latest changes
 from fast syncing mirrors. The script then also falls back to query the
-module at L<http://metacpan.org/> using its seach API.
+module at L<http://metacpan.org/> using its wonderful API.
 
 Upon calling these API hosts, cpanm (1.6004 or later) will send the
 local perl versions to the server in User-Agent string by default. You
@@ -123,32 +134,23 @@ C<PERL_CPANM_HOME> environment variable.
 =head2 Where does this install modules to? Do I need root access?
 
 It installs to wherever ExtUtils::MakeMaker and Module::Build are
-configured to (via C<PERL_MM_OPT> and C<PERL_MB_OPT>).
+configured to (via C<PERL_MM_OPT> and C<PERL_MB_OPT>). So if you're
+using local::lib, then it installs to your local perl5
+directory. Otherwise it installs to the site_perl directory that
+belongs to your perl.
 
-By default, it installs to the site_perl directory that belongs to
-your perl. You can see the locations for that by running C<perl -V>
-and it will be likely something under C</opt/local/perl/...> if you're
-using system perl, or under your home directory if you have built perl
-yourself using perlbrew or plenv.
-
-If you've already configured local::lib on your shell, cpanm respects
-that settings and modules will be installed to your local perl5
-directory.
-
-At a boot time, cpanminus checks whether you have already configured
-local::lib, or have a permission to install modules to the site_perl
-directory.  If neither, i.e. you're using system perl and do not run
-cpanm as a root, it automatically sets up local::lib compatible
+cpanminus at a boot time checks whether you have configured
+local::lib, or have the permission to install modules to the site_perl
+directory.  If neither, it automatically sets up local::lib compatible
 installation path in a C<perl5> directory under your home
-directory.
-
-To avoid this, run C<cpanm> either as a root user, with C<--sudo>
-option, or with C<--local-lib> option.
+directory. To avoid this, run the script as the root user, with
+C<--sudo> option or with C<--local-lib> option.
 
 =head2 cpanminus can't install the module XYZ. Is it a bug?
 
 It is more likely a problem with the distribution itself. cpanminus
-doesn't support or may have issues with distributions such as follows:
+doesn't support or is known to have issues with distributions like as
+follows:
 
 =over 4
 
@@ -158,8 +160,7 @@ Tests that require input from STDIN.
 
 =item *
 
-Build.PL or Makefile.PL that prompts for input even when
-C<PERL_MM_USE_DEFAULT> is enabled.
+Tests that might fail when C<AUTOMATED_TESTING> is enabled.
 
 =item *
 
@@ -168,12 +169,13 @@ Modules that have invalid numeric values as VERSION (such as C<1.1a>)
 =back
 
 These failures can be reported back to the author of the module so
-that they can fix it accordingly, rather than to cpanminus.
+that they can fix it accordingly, rather than me.
 
 =head2 Does cpanm support the feature XYZ of L<CPAN> and L<CPANPLUS>?
 
 Most likely not. Here are the things that cpanm doesn't do by
-itself.
+itself. And it's a feature - you got that from the name I<minus>,
+right?
 
 If you need these features, use L<CPAN>, L<CPANPLUS> or the standalone
 tools that are mentioned.
@@ -214,6 +216,8 @@ The standalone executable contains the following modules embedded.
 
 =item L<CPAN::DistnameInfo> Copyright 2003 Graham Barr
 
+=item L<Parse::CPAN::Meta> Copyright 2006-2009 Adam Kennedy
+
 =item L<local::lib> Copyright 2007-2009 Matt S Trout
 
 =item L<HTTP::Tiny> Copyright 2011 Christian Hansen
